@@ -27,15 +27,12 @@ use List::MoreUtils qw(any none);
 use Lintian::Data;
 use Lintian::SlidingWindow;
 
-use constant EMPTY => q{};
-
 use Moo;
 use namespace::clean;
 
 with 'Lintian::Check';
 
-our $PYTHON_DEPEND
-  = 'python:any | python-dev:any | python-all:any | python-all-dev:any | python2:any | python2-dev:any';
+our $PYTHON_DEPEND= 'python2:any | python2-dev:any';
 our $PYTHON3_DEPEND
   = 'python3:any | python3-dev:any | python3-all:any | python3-all-dev:any';
 our $PYTHON2X_DEPEND = 'python2.7:any | python2.7-dev:any';
@@ -162,10 +159,10 @@ sub source {
         return unless $rules->is_open_ok;
     }
 
-    my $architecture = $processable->fields->value('Architecture') // EMPTY;
+    my $architecture = $processable->fields->value('Architecture');
 
     # If the version field is missing, we assume a neutral non-native one.
-    my $version = $processable->fields->value('Version') // '0-1';
+    my $version = $processable->fields->value('Version') || '0-1';
 
     open(my $rules_fd, '<', $rules->unpacked_path);
 
