@@ -56,32 +56,35 @@ has has_meta => (is => 'rwp', default => 0);
 # The maximum number of *.cmi files to show individually.
 our $MAX_CMI = 3;
 
-sub setup {
+sub setup_installed_files {
     my ($self) = @_;
 
-    open(my $fd, '<',
-        path($self->processable->groupdir)->child('ar-info')->stringify);
-    while (my $line = <$fd>) {
-        chomp($line);
-        if ($line =~ /^(?:\.\/)?([^:]+): (.*)$/) {
-            my ($filename, $contents) = ($1, $2);
-            my $dirname = dirname($filename);
-            for my $entry (split m/ /, $contents) {
-                # Note: a .o may be legitimately in several different .a
-                $self->provided_o->{"$dirname/$entry"} = $filename;
-            }
+    for my $item ($self->processable->installed->sorted_list) {
+
+        my $ar_info = $item->ar_info;
+        next
+          unless scalar keys %{$ar_info};
+
+        # ends in a slash
+        my $dirname = $item->dirname;
+
+        for my $count (keys %{$ar_info}) {
+
+            my $member = $ar_info->{$count}{name};
+            # Note: a .o may be legitimately in several different .a
+            $self->provided_o->{"$dirname$member"} = $item->name
+              if length $member;
         }
     }
-    close($fd);
 
     # is it a library package?
     $self->_set_is_lib_package(1)
-      if $self->package =~ /^lib/;
+      if $self->processable->name =~ /^lib/;
 
     # is it a development package?
     $self->_set_is_dev_package(1)
       if (
-        $self->package =~ m/
+        $self->processable->name =~ m/
            (?: -dev
               |\A camlp[45](?:-extra)?
               |\A ocaml  (?:
@@ -95,7 +98,7 @@ sub setup {
     return;
 }
 
-sub files {
+sub visit_installed_files {
     my ($self, $file) = @_;
 
     # For each .cmxa file, there must be a matching .a file (#528367)
@@ -175,7 +178,7 @@ sub files {
     return;
 }
 
-sub breakdown {
+sub breakdown_installed_files {
     my ($self) = @_;
 
     if ($self->is_dev_package) {
