@@ -34,11 +34,10 @@ use POSIX qw(ENOENT);
 use Time::HiRes qw(gettimeofday tv_interval);
 use Time::Piece;
 
-use Lintian::Processable::Binary;
+use Lintian::Processable::Installable;
 use Lintian::Processable::Buildinfo;
 use Lintian::Processable::Changes;
 use Lintian::Processable::Source;
-use Lintian::Processable::Udeb;
 use Lintian::Util qw(human_bytes);
 
 use constant EMPTY => q{};
@@ -167,10 +166,12 @@ sub add_processable_from_file {
 
     } elsif ($file =~ /\.d?deb$/) {
         # in ubuntu, automatic dbgsym packages end with .ddeb
-        $processable = Lintian::Processable::Binary->new;
+        $processable = Lintian::Processable::Installable->new;
+        $processable->type('binary');
 
     } elsif ($file =~ /\.udeb$/) {
-        $processable = Lintian::Processable::Udeb->new;
+        $processable = Lintian::Processable::Installable->new;
+        $processable->type('udeb');
 
     } elsif ($file =~ /\.changes$/) {
         $processable = Lintian::Processable::Changes->new;
@@ -196,41 +197,14 @@ Process group.
 sub process {
     my ($self, $ignored_overrides, $option, $OUTPUT)= @_;
 
-    $self->processing_start(gmtime->datetime . 'Z');
-
     my $groupname = $self->name;
     local $SIG{__WARN__} = sub { warn "Warning in group $groupname: $_[0]" };
 
+    $self->processing_start(gmtime->datetime . 'Z');
     $OUTPUT->v_msg('Starting on group ' . $self->name);
-
-    my @processables = $self->get_processables;
-    for my $processable (@processables) {
-
-        path($processable->basedir)->mkpath
-          unless -e $processable->basedir;
-
-        if ($processable->can('unpack')) {
-
-            my $unpack_start = [gettimeofday];
-            $OUTPUT->v_msg(
-                'Unpacking packages in processable ' . $processable->name);
-
-            $processable->unpack;
-
-            my $unpack_raw_res = tv_interval($unpack_start);
-            my $unpack_tres = sprintf('%.3fs', $unpack_raw_res);
-
-            $OUTPUT->debug_msg(1,
-                'Unpack of ' . $processable->name . " done ($unpack_tres)");
-            $OUTPUT->perf_log(
-                $self->name . ",total-processable-unpack,$unpack_raw_res");
-        }
-    }
-
-    my $success = 1;
-
     my $timer = [gettimeofday];
 
+    my $success = 1;
     for my $processable ($self->get_processables){
 
         my $declared_overrides;
